[![forthebadge](https://forthebadge.com/images/badges/built-with-love.svg)](https://www.gobolinux.org/)
[![forthebadge](https://forthebadge.com/images/badges/made-with-ruby.svg)](https://www.ruby-lang.org/en/)
[![Gem Version](https://badge.fury.io/rb/extracter.svg)](https://badge.fury.io/rb/extracter)
	
# Extracter

## The primary goal of the extracter gem

This gem can help the user if said user wants to **extract a given
archive**.

## Scope of Extracter

The scope (and goals) for **class Extracter** are really simple: throw
any archive format at it, and the class will try to **extract** it.

It can be used on the commandline as well, via **bin/extracter**.

Note that in order to extract a given archive, some programs must
be available still. On linux this tends to be **tar**, **bzip2**,
**xz** and **gzip**. On windows it is recommended to use **7-zip**.

## How to find out whether a given file is a valid archive

You can find out whether a given input **xyz** is a valid archive by
issuing the following toplevel-method:

    Extracter.is_this_a_valid_archive?(path)

This will return either true or false. In <b>August 2022</b> the
code was adapted slightly to return true no matter if the
file extension is upcased or lowercased. In other words: a
file called <b>foobar.zip</b> will work fine, as will the same 
file but this time called <b>foobar.ZIP</b>. I had the latter issue
when I downloaded a BIOS Firmware update in August 2022 - the
file was .ZIP and Extracter did not work. So that was a tiny
bug in the extracter gem - it really should work on .ZIP
files just fine as well, since these are simply .zip files
anyway.

Keep in mind that not all archive formats have been added so far,
so this will return false even if it should instead return true.

More support for archive formats will be added whenever possible,
as time permits.

## How to extract an archive through class Extracter, in pure ruby

You can use the following method to extract an archive, in ruby,
into a specific target location on the given computer system:

    Extracter.extract_what_to('foo-1.0.tar.xz', '/tmp')

The first argument is the local path to an archive. The second
argument simply specifies the **target**, usually the target
directory. Can't get any simpler than that!

## Colour support

If the **Colours** gem (**gem install colours**) is available then colour
support is possible for **class Extracter::Extracter**.

For class Extracter::Extracter, whether colours are supported is 
determined via the method called **.colours?**. If true then colours
will be used - at the least it will be tried.

If you do not want to have colours, for whatever the reason or use case,
then you can disable this, e. g. through the method call
**.disable_colours** specifically, to give one example for doing so.

## class Extracter::ExtractIt

**class Extracter::ExtractIt** was a standalone .gem (named **extract_it**), 
but since as of **September 2020** it is now part of "module Extracter".

Basically this class is is a wrapper over the class Extracter, which will
extract archives in general. The extraction step will go into the current
working directory.

## What archives and files can be extracted?

**class Extracter** can extract .tar.xz, .tar.bz, .tar.gz, tar.Z,
.zip and numerous other file formats. This requires that tools
such as **tar** or **gzip** or **xz** are installed and available
on the target computer-machine, as we will simply use ruby to
shell out to these other programs. Ruby is the ultimate 'glue'
language after all.

This class can also **extract audio-files** if ffmpeg is installed and
the multimedia_paradise project is available (**gem install
multimedia_paradise**), as well as squashfs files (typically 
.img files). In the latter case, such an .img file will be mounted 
in the current directory. You could then simply copy the content,
to have a 'full' archive situation (mounting means read-only by
deafult in this regard, hence why the copy-operation has to be
done).

Support for extracting **.jar files** - used by Java - has been
added in **May 2020**.

Support for 'extracting' .pdf files has been added in **January 2021**.
This depends on **poppler**, and it is not really an extraction; we
simply convert the file to a .txt (text) file. For this functionality
the **pdf_paradise** project has to be available.

Support for extracting archives on windows via 7zip has been added
in **August 2021**. This was done because I had problems with 'tar'
on windows; using 7zip bypassed these problems, and I needed to
be able to extract archives on windows easily.

## Usage example:

    _ = Extracter.extract_what_to('foobar-1.0.tar.bz2', '/tmp/')

You can also use the .new variant, which goes like so::

    _ = Extracter.new('foo.gz', '/tmp', false) # Yes, you can extract .gz files.
    _.run

The argument false means "do not yet run". You have to invoke
the .run method in that case.

The second argument to the above method is the target location,
the directory where we will extract our archive to.

## strip components

Say that we have a path such as **/home/x/htop/htop-3.0.5.tar.xz**. You
want to extract it, say, into **/tmp/**.

Normally this would create the following directory:

    /tmp/htop-3.0.5/

In most cases this is what the user wants; at the least I expect this
if an archive is correctly tarred up, such as a **.tar.xz** file.

But there are use cases where this is not the case so. For instance,
say that you already did creat such a directory, cd-ed into it and
now just want to extract right **into** this directory. Then you 
don't want to end up with:

    /tmp/htop-3.0.5/htop-3.0.5/

**tar** allows us to avoid this, by using the commandline flag
called **--strip-components=1**.

In **October 2021** I needed this for the rbt-project. Since the
old class Extracter did not support it, and the code was very messy,
I ended up re-writing the project. It should now be better -
at the least cleaner than it once was. And support for the above
is possible as well now; even with a specific method call
(which is **.strip_components()**).

## Extracter.remove_archive_type

If you have a use case where you would like to remove the file
suffix from an archive, such as turning
"https://rubygems.org/rubygems/rubygems-3.3.14.tgz" into
"rubygems-3.3.14" exactly, then you can use
Extracter.remove_archive_type() for this.

Example follows:

    Extracter.remove_archive_type(File.basename("https://rubygems.org/rubygems/rubygems-3.3.14.tgz")) # => "rubygems-3.3.14"


## Contact information and mandatory 2FA coming up in 2022

If your creative mind has ideas and specific suggestions to make this gem
more useful in general, feel free to drop me an email at any time, via:

    shevy@inbox.lt

Before that email I used an email account at Google gmail, but in **2021** I
decided to slowly abandon gmail, for various reasons. In order to limit the
explanation here, allow me to just briefly state that I do not feel as if I
want to promote any Google service anymore when the user becomes the 
product (such as via data collection by upstream services). I feel this is
a hugely flawed business model.

Do keep in mind that responding to emails may take some time, depending on
the amount of work I may have at that moment.

In <b>2022</b> rubygems.org, or rather the corporate overlords who control the
rubygems.org infrastructure these days, decided to make 2FA mandatory for every
gem owner eventually: see
https://blog.rubygems.org/2022/06/13/making-packages-more-secure.html

Mandatory 2FA will eventually be extended to all rubygems.org developers and
maintainers. As I can not use 2FA, for reasons I will skip explaining here,
this means that my projects will eventually be taken over by shopify (or,
correspondingly, whoever effectively controls the rubygems.org ecosystem).
At that point, I no longer have any control what is done to my projects
since shopify (respectively those controlling the gems ecosystem) took away
control here. Not sure at which point ruby became corporate-controlled -
that was not the case several years ago.

Ruby also only allows 2FA users to participate on the issue tracker these
days:

  https://bugs.ruby-lang.org/issues/18800

