# =========================================================================== #
# Gemspec for Project Extracter.
# =========================================================================== #
require 'extracter/version/version.rb'
require 'roebe'

Gem::Specification.new { |s|

  s.name    = 'extracter'
  s.version = Extracter::VERSION
  s.date    = Time.now.strftime('%Y-%m-%d')

  DESCRIPTION = <<-EOF

This fairly small project can be used to extract different
archive formats such as .tar.bz2 or .tbz - archives such
as .gem and .lzma will also work.

You can also extract audio, by making use of class ExtractAudio
(part of the multimedia_paradise gem. The latter is - and should
be - optional, though. If you have no such use case then you 
won't need to install the multimedia_paradise gem.

Usage example:

    require 'extracter'

    Extracter.new('/foo/bla-1.0.tar.bz2')

The second argument that can be passed to the method new()
specifies where this should be extract to.

For example:

    Extracter.new('/foo/bla-1.0.tar.bz2', '/opt')

This would extract to the /opt directory.

You can query whether input is an archive or not via:

  Extracter.is_archive? 'foo.tar.xz'

As of April 2014 we also provide a bin/extract file, so that
you can simply extract something from the commandline.

Since as of November 2018, class Extracter can also "extract"
.iso files. (The .iso will be mounted to a directory that
will be created, actually.)

EOF

  s.summary     = DESCRIPTION
  s.description = DESCRIPTION

  s.authors  = ['Robert A. Heiler']
  s.email    = Roebe.email?
  s.files    = Dir['**/*']
  s.licenses = 'MIT'
  s.homepage = 'https://rubygems.org/gems/extracter'

  # ========================================================================= #
  # Show this when a user installs the project.
  # ========================================================================= #
  s.post_install_message = <<-EOF

  class Extracter can be used to extract archives, such as .tar.gz or
  .zip.

  If you need some help, you can invoke bin/extract via:

      extract --help

  In general, the syntax for extract is kept simple. Just pass in the
  archive that has to be extracted as the first argument to 
  extract ( bin/extract) , and class Extracter will try to extract
  it, if it is a registered archive format.

  In ruby code, you may be able to use class Extracter in this manner:

      require 'extracter'
      Extracter[file_path_here]

  or

      require 'extracter'
      Extracter.new(file_path_here)

  Specific example:

      require 'extracter'
      Extracter.new('htop-2.2.0.tar.xz')

  See the --help option.

  EOF

  s.required_ruby_version     = '>= '+Roebe.third_most_stable_version_of_ruby
  s.required_rubygems_version = '>= '+Gem::VERSION
  s.rubygems_version          = '>= '+Gem::VERSION

  # ========================================================================= #
  # Specify the dependencies for this gem:
  # ========================================================================= #
  s.add_dependency 'opn'

}